---
annotations_creators:
- found
language_creators:
- found
languages:
  ar-en:
  - ar
  - en
  ar-es:
  - ar
  - es
  ar-et:
  - ar
  - et
  ar-fa:
  - ar
  - fa
  ar-fi:
  - ar
  - fi
  ar-fr:
  - ar
  - fr
  ar-ru:
  - ar
  - ru
  ar-so:
  - ar
  - so
  ar-sv:
  - ar
  - sv
  ar-tr:
  - ar
  - tr
  ar-zh:
  - ar
  - zh
  en-es:
  - en
  - es
  en-et:
  - en
  - et
  en-fa:
  - en
  - fa
  en-fi:
  - en
  - fi
  en-fr:
  - en
  - fr
  en-ru:
  - en
  - ru
  en-so:
  - en
  - so
  en-sv:
  - en
  - sv
  en-tr:
  - en
  - tr
  en-zh:
  - en
  - zh
  es-et:
  - es
  - et
  es-fa:
  - es
  - fa
  es-fi:
  - es
  - fi
  es-fr:
  - es
  - fr
  es-ru:
  - es
  - ru
  es-so:
  - es
  - so
  es-sv:
  - es
  - sv
  es-tr:
  - es
  - tr
  es-zh:
  - es
  - zh
  et-fa:
  - et
  - fa
  et-fi:
  - et
  - fi
  et-fr:
  - et
  - fr
  et-ru:
  - et
  - ru
  et-so:
  - et
  - so
  et-sv:
  - et
  - sv
  et-tr:
  - et
  - tr
  et-zh:
  - et
  - zh
  fa-fi:
  - fa
  - fi
  fa-fr:
  - fa
  - fr
  fa-ru:
  - fa
  - ru
  fa-so:
  - fa
  - so
  fa-sv:
  - fa
  - sv
  fa-tr:
  - fa
  - tr
  fa-zh:
  - fa
  - zh
  fi-fr:
  - fi
  - fr
  fi-ru:
  - fi
  - ru
  fi-so:
  - fi
  - so
  fi-sv:
  - fi
  - sv
  fi-tr:
  - fi
  - tr
  fi-zh:
  - fi
  - zh
  fr-ru:
  - fr
  - ru
  fr-so:
  - fr
  - so
  fr-sv:
  - fr
  - sv
  fr-tr:
  - fr
  - tr
  fr-zh:
  - fr
  - zh
  ru-so:
  - ru
  - so
  ru-sv:
  - ru
  - sv
  ru-tr:
  - ru
  - tr
  ru-zh:
  - ru
  - zh
  so-sv:
  - so
  - sv
  so-tr:
  - so
  - tr
  so-zh:
  - so
  - zh
  sv-tr:
  - sv
  - tr
  sv-zh:
  - sv
  - zh
  tr-zh:
  - tr
  - zh
licenses:
- unknown
multilinguality:
- multilingual
size_categories:
- 10K<n<100K
source_datasets:
- original
task_categories:
- conditional-text-generation
task_ids:
- machine-translation
paperswithcode_id: null
---

# Dataset Card for [Dataset Name]

## Table of Contents
- [Dataset Description](#dataset-description)
  - [Dataset Summary](#dataset-summary)
  - [Supported Tasks and Leaderboards](#supported-tasks-and-leaderboards)
  - [Languages](#languages)
- [Dataset Structure](#dataset-structure)
  - [Data Instances](#data-instances)
  - [Data Fields](#data-fields)
  - [Data Splits](#data-splits)
- [Dataset Creation](#dataset-creation)
  - [Curation Rationale](#curation-rationale)
  - [Source Data](#source-data)
  - [Annotations](#annotations)
  - [Personal and Sensitive Information](#personal-and-sensitive-information)
- [Considerations for Using the Data](#considerations-for-using-the-data)
  - [Social Impact of Dataset](#social-impact-of-dataset)
  - [Discussion of Biases](#discussion-of-biases)
  - [Other Known Limitations](#other-known-limitations)
- [Additional Information](#additional-information)
  - [Dataset Curators](#dataset-curators)
  - [Licensing Information](#licensing-information)
  - [Citation Information](#citation-information)
  - [Contributions](#contributions)

## Dataset Description

- **Homepage:**[infopankki](http://opus.nlpl.eu/infopankki-v1.php)
- **Repository:**
- **Paper:**
- **Leaderboard:**
- **Point of Contact:**

### Dataset Summary

A parallel corpus of 12 languages, 66 bitexts.

### Supported Tasks and Leaderboards

The underlying task is machine translation.

### Languages

[More Information Needed]

## Dataset Structure

### Data Instances

[More Information Needed]

### Data Fields

[More Information Needed]

### Data Splits

[More Information Needed]

## Dataset Creation

### Curation Rationale

[More Information Needed]

### Source Data

#### Initial Data Collection and Normalization

[More Information Needed]

#### Who are the source language producers?

[More Information Needed]

### Annotations

#### Annotation process

[More Information Needed]

#### Who are the annotators?

[More Information Needed]

### Personal and Sensitive Information

[More Information Needed]

## Considerations for Using the Data

### Social Impact of Dataset

[More Information Needed]

### Discussion of Biases

[More Information Needed]

### Other Known Limitations

[More Information Needed]

## Additional Information

### Dataset Curators

[More Information Needed]

### Licensing Information

[More Information Needed]

### Citation Information

```
@InProceedings{TIEDEMANN12.463,
  author = {J�rg Tiedemann},
  title = {Parallel Data, Tools and Interfaces in OPUS},
  booktitle = {Proceedings of the Eight International Conference on Language Resources and Evaluation (LREC'12)},
  year = {2012},
  month = {may},
  date = {23-25},
  address = {Istanbul, Turkey},
  editor = {Nicoletta Calzolari (Conference Chair) and Khalid Choukri and Thierry Declerck and Mehmet Ugur Dogan and Bente Maegaard and Joseph Mariani and Jan Odijk and Stelios Piperidis},
  publisher = {European Language Resources Association (ELRA)},
  isbn = {978-2-9517408-7-7},
  language = {english}
}
```

### Contributions

Thanks to [@patil-suraj](https://github.com/patil-suraj) for adding this dataset.